==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/it-IT/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Campi Personalizzati',
    'manage'                    => 'Gestire',
    'field'		                => 'Campo',
    'about_fieldsets_title'		=> 'Fileldsets',
    'about_fieldsets_text'		=> 'I set di campi consentono di creare gruppi di campi personalizzati che vengono spesso riutilizzati per tipi di modelli di asset specifici.',
    'custom_format'             => 'Formato Regex personalizzato...',
    'encrypt_field'      	        => 'Crittografare il valore di questo campo nel database',
    'encrypt_field_help'      => 'ATTENZIONE: Se il campo viene crittografato non sarà possibile cercarlo.',
    'encrypted'      	        => 'Crittografato',
    'fieldset'      	        => 'Campo',
    'qty_fields'      	      => 'Campi quantità',
    'fieldsets'      	        => 'Campi',
    'fieldset_name'           => 'Nome Campo',
    'field_name'              => 'Nome campo',
    'field_values'            => 'Valori del campo',
    'field_values_help'       => 'Aggiungi opzioni selezionabili, una per riga. Le righe vuote diverse dalla prima riga saranno ignorate.',
    'field_element'           => 'Elemento del form',
    'field_element_short'     => 'Elemento',
    'field_format'            => 'Formato',
    'field_custom_format'     => 'Formato personalizzato',
    'field_custom_format_help'     => 'Questo campo ti permette di utilizzare un\'espressione regex per la validazione. Deve iniziare con "regex:" - ad esempio, per validare il valore di un campo personalizzato contenente un IMEI (15 cifre numeriche), userai <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'Obbligatorio',
    'req'   		              => 'Obbl.',
    'used_by_models'   		    => 'Usato dai Modelli',
    'order'   		            => 'Ordine',
    'create_fieldset'         => 'Nuovo Campo',
    'update_fieldset'         => 'Aggiorna Fieldset',
    'fieldset_does_not_exist'   => 'Il fieldset :id non esiste',
    'fieldset_updated'         => 'Fieldset aggiornato',
    'create_fieldset_title' => 'Crea un nuovo campo',
    'create_field'            => 'Nuovo campo personalizzato',
    'create_field_title' => 'Crea un nuovo campo personalizzato',
    'value_encrypted'      	        => 'Il valore di questo campo viene crittografato nel database. Solo gli utenti amministratori saranno in grado di visualizzare il valore decrittografato',
    'show_in_email'     => 'Includere il valore di questo campo nelle e-mail di assegnazione inviate all\'utente? I campi crittografati non possono essere inclusi nelle e-mail',
    'show_in_email_short'     => 'Includi nelle email.',
    'help_text' => 'Testo guida',
    'help_text_description' => 'Questo è un testo facoltativo che apparirà sotto gli elementi del modulo durante la modifica di una risorsa per fornire il contesto sul campo.',
    'about_custom_fields_title' => 'Informazioni sui campi personalizzati',
    'about_custom_fields_text' => 'I campi personalizzati consentono di aggiungere attributi arbitrari alle risorse.',
    'add_field_to_fieldset' => 'Aggiungi campo a Fieldset',
    'make_optional' => 'Obbligatorio: fare clic per renderlo opzionale',
    'make_required' => 'Facoltativo: fare clic per renderlo obbligatorio',
    'reorder' => 'Riordina',
    'db_field' => 'Campo DB',
    'db_convert_warning' => 'AVVERTIMENTO. Questo campo è nella tabella dei campi personalizzati come <code>:db_column</code> ma dovrebbe essere <code>:expected</code>.',
    'is_unique' => 'Questo valore deve essere univoco per tutti i beni',
    'unique' => 'Univoco',
    'display_in_user_view' => 'Permetti all\'utente di visualizzare questi valori nella pagina Visualizza Beni Assegnati',
    'display_in_user_view_table' => 'Visibile all\'utente',
    'auto_add_to_fieldsets' => 'Aggiungi automaticamente a ogni nuovo campo',
    'add_to_preexisting_fieldsets' => 'Aggiungi a tutti i campi esistenti',
    'show_in_listview' => 'Mostra nelle viste elenco per default. Gli utenti autorizzati potranno comunque mostrare/nascondere con il selettore colonne',
    'show_in_listview_short' => 'Mostra nelle liste',
    'show_in_requestable_list_short' => 'Mostra nella lista beni richiedibili',
    'show_in_requestable_list' => 'Mostra nella lista dei beni richiedibili. I valori criptati non verranno mostrati',
    'encrypted_options' => 'Questo campo è criptato, quindi alcune opzioni di visualizzazione non saranno disponibili.',

];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/it-IT/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Campi Personalizzati',
    'manage'                    => 'Gestire',
    'field'		                => 'Campo',
    'about_fieldsets_title'		=> 'Fileldsets',
    'about_fieldsets_text'		=> 'I set di campi consentono di creare gruppi di campi personalizzati che vengono spesso riutilizzati per tipi di modelli di asset specifici.',
    'custom_format'             => 'Formato Regex personalizzato...',
    'encrypt_field'      	        => 'Crittografare il valore di questo campo nel database',
    'encrypt_field_help'      => 'ATTENZIONE: Se il campo viene crittografato non sarà possibile cercarlo.',
    'encrypted'      	        => 'Crittografato',
    'fieldset'      	        => 'Campo',
    'qty_fields'      	      => 'Campi quantità',
    'fieldsets'      	        => 'Campi',
    'fieldset_name'           => 'Nome Campo',
    'field_name'              => 'Nome campo',
    'field_values'            => 'Valori del campo',
    'field_values_help'       => 'Aggiungi opzioni selezionabili, una per riga. Le righe vuote diverse dalla prima riga saranno ignorate.',
    'field_element'           => 'Elemento del form',
    'field_element_short'     => 'Elemento',
    'field_format'            => 'Formato',
    'field_custom_format'     => 'Formato personalizzato',
    'field_custom_format_help'     => 'Questo campo ti permette di utilizzare un\'espressione regex per la validazione. Deve iniziare con "regex:" - ad esempio, per validare il valore di un campo personalizzato contenente un IMEI (15 cifre numeriche), userai <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'Obbligatorio',
    'req'   		              => 'Obbl.',
    'used_by_models'   		    => 'Usato dai Modelli',
    'order'   		            => 'Ordine',
    'create_fieldset'         => 'Nuovo Campo',
    'update_fieldset'         => 'Aggiorna Fieldset',
    'fieldset_does_not_exist'   => 'Il fieldset :id non esiste',
    'fieldset_updated'         => 'Fieldset aggiornato',
    'create_fieldset_title' => 'Crea un nuovo campo',
    'create_field'            => 'Nuovo campo personalizzato',
    'create_field_title' => 'Crea un nuovo campo personalizzato',
    'value_encrypted'      	        => 'Il valore di questo campo viene crittografato nel database. Solo gli utenti amministratori saranno in grado di visualizzare il valore decrittografato',
    'show_in_email'     => 'Includere il valore di questo campo nelle e-mail di assegnazione inviate all\'utente? I campi crittografati non possono essere inclusi nelle e-mail',
    'show_in_email_short' => 'Includi nelle email',
    'help_text' => 'Testo guida',
    'help_text_description' => 'Questo è un testo facoltativo che apparirà sotto gli elementi del modulo durante la modifica di una risorsa per fornire il contesto sul campo.',
    'about_custom_fields_title' => 'Informazioni sui campi personalizzati',
    'about_custom_fields_text' => 'I campi personalizzati consentono di aggiungere attributi arbitrari alle risorse.',
    'add_field_to_fieldset' => 'Aggiungi campo a Fieldset',
    'make_optional' => 'Obbligatorio: fare clic per renderlo opzionale',
    'make_required' => 'Facoltativo: fare clic per renderlo obbligatorio',
    'reorder' => 'Riordina',
    'db_field' => 'Campo DB',
    'db_convert_warning' => 'AVVERTIMENTO. Questo campo è nella tabella dei campi personalizzati come <code>:db_column</code> ma dovrebbe essere <code>:expected</code>.',
    'is_unique' => 'Questo valore deve essere univoco per tutti i beni',
    'unique' => 'Univoco',
    'display_in_user_view' => 'Permetti all\'utente di visualizzare questi valori nella pagina Visualizza Beni Assegnati',
    'display_in_user_view_table' => 'Visibile all\'utente',
    'auto_add_to_fieldsets' => 'Aggiungi automaticamente a ogni nuovo campo',
    'add_to_preexisting_fieldsets' => 'Aggiungi a tutti i campi esistenti',
    'show_in_listview' => 'Mostra nelle viste elenco per default. Gli utenti autorizzati potranno comunque mostrare/nascondere con il selettore colonne',
    'show_in_listview_short' => 'Mostra nelle liste',
    'show_in_requestable_list_short' => 'Mostra nella lista beni richiedibili',
    'show_in_requestable_list' => 'Mostra nella lista dei beni richiedibili. I valori criptati non verranno mostrati',
    'encrypted_options' => 'Questo campo è criptato, quindi alcune opzioni di visualizzazione non saranno disponibili.',
    'display_checkin' => 'Mostra nei moduli di check-in',
    'display_checkout' => 'Mostra nei moduli di assegnazione',

];
